# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: src/ray/protobuf/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='src/ray/protobuf/common.proto',
  package='ray.rpc',
  syntax='proto3',
  serialized_options=b'\n\030io.ray.runtime.generated',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dsrc/ray/protobuf/common.proto\x12\x07ray.rpc\"v\n\x07\x41\x64\x64ress\x12\x1b\n\traylet_id\x18\x01 \x01(\x0cR\x08rayletId\x12\x1d\n\nip_address\x18\x02 \x01(\tR\tipAddress\x12\x12\n\x04port\x18\x03 \x01(\x05R\x04port\x12\x1b\n\tworker_id\x18\x04 \x01(\x0cR\x08workerId\"z\n\x16JavaFunctionDescriptor\x12\x1d\n\nclass_name\x18\x01 \x01(\tR\tclassName\x12#\n\rfunction_name\x18\x02 \x01(\tR\x0c\x66unctionName\x12\x1c\n\tsignature\x18\x03 \x01(\tR\tsignature\"\xa4\x01\n\x18PythonFunctionDescriptor\x12\x1f\n\x0bmodule_name\x18\x01 \x01(\tR\nmoduleName\x12\x1d\n\nclass_name\x18\x02 \x01(\tR\tclassName\x12#\n\rfunction_name\x18\x03 \x01(\tR\x0c\x66unctionName\x12#\n\rfunction_hash\x18\x04 \x01(\tR\x0c\x66unctionHash\"W\n\x15\x43ppFunctionDescriptor\x12\x19\n\x08lib_name\x18\x01 \x01(\tR\x07libName\x12#\n\rfunction_name\x18\x04 \x01(\tR\x0c\x66unctionName\"\xc5\x02\n\x12\x46unctionDescriptor\x12[\n\x18java_function_descriptor\x18\x01 \x01(\x0b\x32\x1f.ray.rpc.JavaFunctionDescriptorH\x00R\x16javaFunctionDescriptor\x12\x61\n\x1apython_function_descriptor\x18\x02 \x01(\x0b\x32!.ray.rpc.PythonFunctionDescriptorH\x00R\x18pythonFunctionDescriptor\x12X\n\x17\x63pp_function_descriptor\x18\x03 \x01(\x0b\x32\x1e.ray.rpc.CppFunctionDescriptorH\x00R\x15\x63ppFunctionDescriptorB\x15\n\x13\x66unction_descriptor\"\xae\x01\n\x0cRayException\x12-\n\x08language\x18\x01 \x01(\x0e\x32\x11.ray.rpc.LanguageR\x08language\x12\x31\n\x14serialized_exception\x18\x02 \x01(\x0cR\x13serializedException\x12<\n\x1a\x66ormatted_exception_string\x18\x03 \x01(\tR\x18\x66ormattedExceptionString\";\n\nRuntimeEnv\x12\x19\n\x08raw_json\x18\x01 \x01(\tR\x07rawJson\x12\x12\n\x04uris\x18\x02 \x03(\tR\x04uris\"\x90\x0c\n\x08TaskSpec\x12%\n\x04type\x18\x01 \x01(\x0e\x32\x11.ray.rpc.TaskTypeR\x04type\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12-\n\x08language\x18\x03 \x01(\x0e\x32\x11.ray.rpc.LanguageR\x08language\x12L\n\x13\x66unction_descriptor\x18\x04 \x01(\x0b\x32\x1b.ray.rpc.FunctionDescriptorR\x12\x66unctionDescriptor\x12\x15\n\x06job_id\x18\x05 \x01(\x0cR\x05jobId\x12\x17\n\x07task_id\x18\x06 \x01(\x0cR\x06taskId\x12$\n\x0eparent_task_id\x18\x07 \x01(\x0cR\x0cparentTaskId\x12%\n\x0eparent_counter\x18\x08 \x01(\x04R\rparentCounter\x12\x1b\n\tcaller_id\x18\t \x01(\x0cR\x08\x63\x61llerId\x12\x37\n\x0e\x63\x61ller_address\x18\n \x01(\x0b\x32\x10.ray.rpc.AddressR\rcallerAddress\x12$\n\x04\x61rgs\x18\x0b \x03(\x0b\x32\x10.ray.rpc.TaskArgR\x04\x61rgs\x12\x1f\n\x0bnum_returns\x18\x0c \x01(\x04R\nnumReturns\x12W\n\x12required_resources\x18\r \x03(\x0b\x32(.ray.rpc.TaskSpec.RequiredResourcesEntryR\x11requiredResources\x12s\n\x1crequired_placement_resources\x18\x0e \x03(\x0b\x32\x31.ray.rpc.TaskSpec.RequiredPlacementResourcesEntryR\x1arequiredPlacementResources\x12W\n\x18\x61\x63tor_creation_task_spec\x18\x0f \x01(\x0b\x32\x1e.ray.rpc.ActorCreationTaskSpecR\x15\x61\x63torCreationTaskSpec\x12>\n\x0f\x61\x63tor_task_spec\x18\x10 \x01(\x0b\x32\x16.ray.rpc.ActorTaskSpecR\ractorTaskSpec\x12\x1f\n\x0bmax_retries\x18\x11 \x01(\x05R\nmaxRetries\x12,\n\x12placement_group_id\x18\x12 \x01(\x0cR\x10placementGroupId\x12?\n\x1cplacement_group_bundle_index\x18\x13 \x01(\x03R\x19placementGroupBundleIndex\x12L\n#placement_group_capture_child_tasks\x18\x14 \x01(\x08R\x1fplacementGroupCaptureChildTasks\x12y\n\x1eoverride_environment_variables\x18\x15 \x03(\x0b\x32\x33.ray.rpc.TaskSpec.OverrideEnvironmentVariablesEntryR\x1coverrideEnvironmentVariables\x12%\n\x0eskip_execution\x18\x16 \x01(\x08R\rskipExecution\x12/\n\x13\x64\x65\x62ugger_breakpoint\x18\x17 \x01(\x0cR\x12\x64\x65\x62uggerBreakpoint\x12\x34\n\x16serialized_runtime_env\x18\x18 \x01(\tR\x14serializedRuntimeEnv\x1a\x44\n\x16RequiredResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1aM\n\x1fRequiredPlacementResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\x1aO\n!OverrideEnvironmentVariablesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xd2\x02\n\x06\x42undle\x12=\n\tbundle_id\x18\x01 \x01(\x0b\x32 .ray.rpc.Bundle.BundleIdentifierR\x08\x62undleId\x12I\n\x0eunit_resources\x18\x02 \x03(\x0b\x32\".ray.rpc.Bundle.UnitResourcesEntryR\runitResources\x12\x17\n\x07node_id\x18\x03 \x01(\x0cR\x06nodeId\x1a\x63\n\x10\x42undleIdentifier\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\x12!\n\x0c\x62undle_index\x18\x02 \x01(\x05R\x0b\x62undleIndex\x1a@\n\x12UnitResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\x82\x03\n\x12PlacementGroupSpec\x12,\n\x12placement_group_id\x18\x01 \x01(\x0cR\x10placementGroupId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12)\n\x07\x62undles\x18\x03 \x03(\x0b\x32\x0f.ray.rpc.BundleR\x07\x62undles\x12\x36\n\x08strategy\x18\x04 \x01(\x0e\x32\x1a.ray.rpc.PlacementStrategyR\x08strategy\x12$\n\x0e\x63reator_job_id\x18\x05 \x01(\x0cR\x0c\x63reatorJobId\x12(\n\x10\x63reator_actor_id\x18\x06 \x01(\x0cR\x0e\x63reatorActorId\x12(\n\x10\x63reator_job_dead\x18\x07 \x01(\x08R\x0e\x63reatorJobDead\x12,\n\x12\x63reator_actor_dead\x18\x08 \x01(\x08R\x10\x63reatorActorDead\x12\x1f\n\x0bis_detached\x18\t \x01(\x08R\nisDetached\"e\n\x0fObjectReference\x12\x1b\n\tobject_id\x18\x01 \x01(\x0cR\x08objectId\x12\x35\n\rowner_address\x18\x02 \x01(\x0b\x32\x10.ray.rpc.AddressR\x0cownerAddress\"\xbd\x02\n\x14ObjectReferenceCount\x12\x36\n\treference\x18\x01 \x01(\x0b\x32\x18.ray.rpc.ObjectReferenceR\treference\x12\"\n\rhas_local_ref\x18\x02 \x01(\x08R\x0bhasLocalRef\x12.\n\tborrowers\x18\x03 \x03(\x0b\x32\x10.ray.rpc.AddressR\tborrowers\x12\x44\n\x11stored_in_objects\x18\x04 \x03(\x0b\x32\x18.ray.rpc.ObjectReferenceR\x0fstoredInObjects\x12\x37\n\x18\x63ontained_in_borrowed_id\x18\x05 \x01(\x0cR\x15\x63ontainedInBorrowedId\x12\x1a\n\x08\x63ontains\x18\x06 \x03(\x0cR\x08\x63ontains\"\xa0\x01\n\x07TaskArg\x12\x37\n\nobject_ref\x18\x01 \x01(\x0b\x32\x18.ray.rpc.ObjectReferenceR\tobjectRef\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12\x1a\n\x08metadata\x18\x03 \x01(\x0cR\x08metadata\x12,\n\x12nested_inlined_ids\x18\x04 \x03(\x0cR\x10nestedInlinedIds\"\xe4\x02\n\x15\x41\x63torCreationTaskSpec\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\x0cR\x07\x61\x63torId\x12,\n\x12max_actor_restarts\x18\x03 \x01(\x03R\x10maxActorRestarts\x12(\n\x10max_task_retries\x18\x04 \x01(\x03R\x0emaxTaskRetries\x12\x34\n\x16\x64ynamic_worker_options\x18\x05 \x03(\tR\x14\x64ynamicWorkerOptions\x12\'\n\x0fmax_concurrency\x18\x06 \x01(\x05R\x0emaxConcurrency\x12\x1f\n\x0bis_detached\x18\x07 \x01(\x08R\nisDetached\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x1d\n\nis_asyncio\x18\t \x01(\x08R\tisAsyncio\x12%\n\x0e\x65xtension_data\x18\n \x01(\tR\rextensionData\"\xe0\x01\n\rActorTaskSpec\x12\x19\n\x08\x61\x63tor_id\x18\x02 \x01(\x0cR\x07\x61\x63torId\x12\x42\n\x1e\x61\x63tor_creation_dummy_object_id\x18\x04 \x01(\x0cR\x1a\x61\x63torCreationDummyObjectId\x12#\n\ractor_counter\x18\x05 \x01(\x04R\x0c\x61\x63torCounter\x12K\n#previous_actor_task_dummy_object_id\x18\x07 \x01(\x0cR\x1epreviousActorTaskDummyObjectId\"]\n\x11TaskExecutionSpec\x12%\n\x0elast_timestamp\x18\x02 \x01(\x01R\rlastTimestamp\x12!\n\x0cnum_forwards\x18\x03 \x01(\x04R\x0bnumForwards\"\x82\x01\n\x04Task\x12.\n\ttask_spec\x18\x01 \x01(\x0b\x32\x11.ray.rpc.TaskSpecR\x08taskSpec\x12J\n\x13task_execution_spec\x18\x02 \x01(\x0b\x32\x1a.ray.rpc.TaskExecutionSpecR\x11taskExecutionSpec\">\n\nResourceId\x12\x14\n\x05index\x18\x01 \x01(\x03R\x05index\x12\x1a\n\x08quantity\x18\x02 \x01(\x01R\x08quantity\"^\n\x10ResourceMapEntry\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x36\n\x0cresource_ids\x18\x02 \x03(\x0b\x32\x13.ray.rpc.ResourceIdR\x0bresourceIds\"\xf4\x03\n\x08ViewData\x12\x1b\n\tview_name\x18\x01 \x01(\tR\x08viewName\x12\x35\n\x08measures\x18\x02 \x03(\x0b\x32\x19.ray.rpc.ViewData.MeasureR\x08measures\x1a\x93\x03\n\x07Measure\x12\x12\n\x04tags\x18\x01 \x01(\tR\x04tags\x12\x1b\n\tint_value\x18\x02 \x01(\x03R\x08intValue\x12!\n\x0c\x64ouble_value\x18\x03 \x01(\x01R\x0b\x64oubleValue\x12)\n\x10\x64istribution_min\x18\x04 \x01(\x01R\x0f\x64istributionMin\x12+\n\x11\x64istribution_mean\x18\x05 \x01(\x01R\x10\x64istributionMean\x12)\n\x10\x64istribution_max\x18\x06 \x01(\x01R\x0f\x64istributionMax\x12-\n\x12\x64istribution_count\x18\x07 \x01(\x01R\x11\x64istributionCount\x12\x44\n\x1e\x64istribution_bucket_boundaries\x18\x08 \x03(\x01R\x1c\x64istributionBucketBoundaries\x12<\n\x1a\x64istribution_bucket_counts\x18\t \x03(\x01R\x18\x64istributionBucketCounts\"\xa3\x02\n\rObjectRefInfo\x12\x1b\n\tobject_id\x18\x01 \x01(\x0cR\x08objectId\x12\x1b\n\tcall_site\x18\x02 \x01(\tR\x08\x63\x61llSite\x12\x1f\n\x0bobject_size\x18\x03 \x01(\x03R\nobjectSize\x12&\n\x0flocal_ref_count\x18\x04 \x01(\x03R\rlocalRefCount\x12\x37\n\x18submitted_task_ref_count\x18\x05 \x01(\x03R\x15submittedTaskRefCount\x12,\n\x12\x63ontained_in_owned\x18\x06 \x03(\x0cR\x10\x63ontainedInOwned\x12(\n\x10pinned_in_memory\x18\x07 \x01(\x08R\x0epinnedInMemory\"\xab\x01\n\x13ResourceAllocations\x12P\n\x0eresource_slots\x18\x01 \x03(\x0b\x32).ray.rpc.ResourceAllocations.ResourceSlotR\rresourceSlots\x1a\x42\n\x0cResourceSlot\x12\x12\n\x04slot\x18\x01 \x01(\x03R\x04slot\x12\x1e\n\nallocation\x18\x02 \x01(\x01R\nallocation\"\xfe\x08\n\x0f\x43oreWorkerStats\x12*\n\x11\x63urrent_task_desc\x18\x01 \x01(\tR\x0f\x63urrentTaskDesc\x12*\n\x11num_pending_tasks\x18\x02 \x01(\x05R\x0fnumPendingTasks\x12\x36\n\x18num_object_refs_in_scope\x18\x03 \x01(\x05R\x14numObjectRefsInScope\x12*\n\x11\x63urrent_task_name\x18\x04 \x01(\tR\x0f\x63urrentTaskName\x12\x33\n\x16\x63urrent_task_func_desc\x18\x05 \x01(\tR\x13\x63urrentTaskFuncDesc\x12\x1d\n\nip_address\x18\x07 \x01(\tR\tipAddress\x12\x12\n\x04port\x18\x08 \x01(\x03R\x04port\x12\x19\n\x08\x61\x63tor_id\x18\t \x01(\x0cR\x07\x61\x63torId\x12R\n\x0eused_resources\x18\n \x03(\x0b\x32+.ray.rpc.CoreWorkerStats.UsedResourcesEntryR\rusedResources\x12O\n\rwebui_display\x18\x0b \x03(\x0b\x32*.ray.rpc.CoreWorkerStats.WebuiDisplayEntryR\x0cwebuiDisplay\x12\"\n\rnum_in_plasma\x18\x0c \x01(\x05R\x0bnumInPlasma\x12*\n\x11num_local_objects\x18\r \x01(\x05R\x0fnumLocalObjects\x12\x37\n\x18used_object_store_memory\x18\x0e \x01(\x03R\x15usedObjectStoreMemory\x12*\n\x11task_queue_length\x18\x0f \x01(\x05R\x0ftaskQueueLength\x12,\n\x12num_executed_tasks\x18\x10 \x01(\x05R\x10numExecutedTasks\x12\x1f\n\x0b\x61\x63tor_title\x18\x11 \x01(\tR\nactorTitle\x12\x37\n\x0bobject_refs\x18\x12 \x03(\x0b\x32\x16.ray.rpc.ObjectRefInfoR\nobjectRefs\x12\x15\n\x06job_id\x18\x13 \x01(\x0cR\x05jobId\x12\x1b\n\tworker_id\x18\x14 \x01(\x0cR\x08workerId\x12-\n\x08language\x18\x15 \x01(\x0e\x32\x11.ray.rpc.LanguageR\x08language\x12\x10\n\x03pid\x18\x16 \x01(\rR\x03pid\x12\x34\n\x0bworker_type\x18\x17 \x01(\x0e\x32\x13.ray.rpc.WorkerTypeR\nworkerType\x1a^\n\x12UsedResourcesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32\x1c.ray.rpc.ResourceAllocationsR\x05value:\x02\x38\x01\x1a?\n\x11WebuiDisplayEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x87\x02\n\x0bMetricPoint\x12\x1f\n\x0bmetric_name\x18\x01 \x01(\tR\nmetricName\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12\x14\n\x05value\x18\x03 \x01(\x01R\x05value\x12\x32\n\x04tags\x18\x04 \x03(\x0b\x32\x1e.ray.rpc.MetricPoint.TagsEntryR\x04tags\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x14\n\x05units\x18\x06 \x01(\tR\x05units\x1a\x37\n\tTagsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*)\n\x08Language\x12\n\n\x06PYTHON\x10\x00\x12\x08\n\x04JAVA\x10\x01\x12\x07\n\x03\x43PP\x10\x02*[\n\nWorkerType\x12\n\n\x06WORKER\x10\x00\x12\n\n\x06\x44RIVER\x10\x01\x12\x10\n\x0cSPILL_WORKER\x10\x02\x12\x12\n\x0eRESTORE_WORKER\x10\x03\x12\x0f\n\x0bUTIL_WORKER\x10\x04*U\n\x08TaskType\x12\x0f\n\x0bNORMAL_TASK\x10\x00\x12\x17\n\x13\x41\x43TOR_CREATION_TASK\x10\x01\x12\x0e\n\nACTOR_TASK\x10\x02\x12\x0f\n\x0b\x44RIVER_TASK\x10\x03*\xad\x01\n\tErrorType\x12\x0f\n\x0bWORKER_DIED\x10\x00\x12\x0e\n\nACTOR_DIED\x10\x01\x12\x1c\n\x18OBJECT_UNRECONSTRUCTABLE\x10\x02\x12\x1c\n\x18TASK_EXECUTION_EXCEPTION\x10\x03\x12\x14\n\x10OBJECT_IN_PLASMA\x10\x04\x12\x12\n\x0eTASK_CANCELLED\x10\x05\x12\x19\n\x15\x41\x43TOR_CREATION_FAILED\x10\x06*\x9d\x01\n\x0eWorkerExitType\x12\x15\n\x11SYSTEM_ERROR_EXIT\x10\x00\x12\x11\n\rINTENDED_EXIT\x10\x01\x12\x1c\n\x18UNUSED_RESOURCE_RELEASED\x10\x02\x12\x1b\n\x17PLACEMENT_GROUP_REMOVED\x10\x03\x12\x17\n\x13\x43REATION_TASK_ERROR\x10\x04\x12\r\n\tIDLE_EXIT\x10\x05*M\n\x11PlacementStrategy\x12\x08\n\x04PACK\x10\x00\x12\n\n\x06SPREAD\x10\x01\x12\x0f\n\x0bSTRICT_PACK\x10\x02\x12\x11\n\rSTRICT_SPREAD\x10\x03\x42\x1a\n\x18io.ray.runtime.generatedb\x06proto3'
)

_LANGUAGE = _descriptor.EnumDescriptor(
  name='Language',
  full_name='ray.rpc.Language',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PYTHON', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JAVA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CPP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7343,
  serialized_end=7384,
)
_sym_db.RegisterEnumDescriptor(_LANGUAGE)

Language = enum_type_wrapper.EnumTypeWrapper(_LANGUAGE)
_WORKERTYPE = _descriptor.EnumDescriptor(
  name='WorkerType',
  full_name='ray.rpc.WorkerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WORKER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPILL_WORKER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESTORE_WORKER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UTIL_WORKER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7386,
  serialized_end=7477,
)
_sym_db.RegisterEnumDescriptor(_WORKERTYPE)

WorkerType = enum_type_wrapper.EnumTypeWrapper(_WORKERTYPE)
_TASKTYPE = _descriptor.EnumDescriptor(
  name='TaskType',
  full_name='ray.rpc.TaskType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NORMAL_TASK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTOR_CREATION_TASK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTOR_TASK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRIVER_TASK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7479,
  serialized_end=7564,
)
_sym_db.RegisterEnumDescriptor(_TASKTYPE)

TaskType = enum_type_wrapper.EnumTypeWrapper(_TASKTYPE)
_ERRORTYPE = _descriptor.EnumDescriptor(
  name='ErrorType',
  full_name='ray.rpc.ErrorType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WORKER_DIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTOR_DIED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_UNRECONSTRUCTABLE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TASK_EXECUTION_EXCEPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OBJECT_IN_PLASMA', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TASK_CANCELLED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTOR_CREATION_FAILED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7567,
  serialized_end=7740,
)
_sym_db.RegisterEnumDescriptor(_ERRORTYPE)

ErrorType = enum_type_wrapper.EnumTypeWrapper(_ERRORTYPE)
_WORKEREXITTYPE = _descriptor.EnumDescriptor(
  name='WorkerExitType',
  full_name='ray.rpc.WorkerExitType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYSTEM_ERROR_EXIT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTENDED_EXIT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNUSED_RESOURCE_RELEASED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLACEMENT_GROUP_REMOVED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATION_TASK_ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IDLE_EXIT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7743,
  serialized_end=7900,
)
_sym_db.RegisterEnumDescriptor(_WORKEREXITTYPE)

WorkerExitType = enum_type_wrapper.EnumTypeWrapper(_WORKEREXITTYPE)
_PLACEMENTSTRATEGY = _descriptor.EnumDescriptor(
  name='PlacementStrategy',
  full_name='ray.rpc.PlacementStrategy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PACK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPREAD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRICT_PACK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STRICT_SPREAD', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7902,
  serialized_end=7979,
)
_sym_db.RegisterEnumDescriptor(_PLACEMENTSTRATEGY)

PlacementStrategy = enum_type_wrapper.EnumTypeWrapper(_PLACEMENTSTRATEGY)
PYTHON = 0
JAVA = 1
CPP = 2
WORKER = 0
DRIVER = 1
SPILL_WORKER = 2
RESTORE_WORKER = 3
UTIL_WORKER = 4
NORMAL_TASK = 0
ACTOR_CREATION_TASK = 1
ACTOR_TASK = 2
DRIVER_TASK = 3
WORKER_DIED = 0
ACTOR_DIED = 1
OBJECT_UNRECONSTRUCTABLE = 2
TASK_EXECUTION_EXCEPTION = 3
OBJECT_IN_PLASMA = 4
TASK_CANCELLED = 5
ACTOR_CREATION_FAILED = 6
SYSTEM_ERROR_EXIT = 0
INTENDED_EXIT = 1
UNUSED_RESOURCE_RELEASED = 2
PLACEMENT_GROUP_REMOVED = 3
CREATION_TASK_ERROR = 4
IDLE_EXIT = 5
PACK = 0
SPREAD = 1
STRICT_PACK = 2
STRICT_SPREAD = 3



_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='ray.rpc.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raylet_id', full_name='ray.rpc.Address.raylet_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rayletId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='ray.rpc.Address.ip_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ipAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='ray.rpc.Address.port', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='port', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_id', full_name='ray.rpc.Address.worker_id', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=42,
  serialized_end=160,
)


_JAVAFUNCTIONDESCRIPTOR = _descriptor.Descriptor(
  name='JavaFunctionDescriptor',
  full_name='ray.rpc.JavaFunctionDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_name', full_name='ray.rpc.JavaFunctionDescriptor.class_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='className', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_name', full_name='ray.rpc.JavaFunctionDescriptor.function_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='functionName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='ray.rpc.JavaFunctionDescriptor.signature', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='signature', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=284,
)


_PYTHONFUNCTIONDESCRIPTOR = _descriptor.Descriptor(
  name='PythonFunctionDescriptor',
  full_name='ray.rpc.PythonFunctionDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='module_name', full_name='ray.rpc.PythonFunctionDescriptor.module_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='moduleName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='ray.rpc.PythonFunctionDescriptor.class_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='className', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_name', full_name='ray.rpc.PythonFunctionDescriptor.function_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='functionName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_hash', full_name='ray.rpc.PythonFunctionDescriptor.function_hash', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='functionHash', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=287,
  serialized_end=451,
)


_CPPFUNCTIONDESCRIPTOR = _descriptor.Descriptor(
  name='CppFunctionDescriptor',
  full_name='ray.rpc.CppFunctionDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lib_name', full_name='ray.rpc.CppFunctionDescriptor.lib_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='libName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_name', full_name='ray.rpc.CppFunctionDescriptor.function_name', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='functionName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=540,
)


_FUNCTIONDESCRIPTOR = _descriptor.Descriptor(
  name='FunctionDescriptor',
  full_name='ray.rpc.FunctionDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='java_function_descriptor', full_name='ray.rpc.FunctionDescriptor.java_function_descriptor', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='javaFunctionDescriptor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='python_function_descriptor', full_name='ray.rpc.FunctionDescriptor.python_function_descriptor', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pythonFunctionDescriptor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpp_function_descriptor', full_name='ray.rpc.FunctionDescriptor.cpp_function_descriptor', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='cppFunctionDescriptor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='function_descriptor', full_name='ray.rpc.FunctionDescriptor.function_descriptor',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=543,
  serialized_end=868,
)


_RAYEXCEPTION = _descriptor.Descriptor(
  name='RayException',
  full_name='ray.rpc.RayException',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language', full_name='ray.rpc.RayException.language', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='language', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serialized_exception', full_name='ray.rpc.RayException.serialized_exception', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='serializedException', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formatted_exception_string', full_name='ray.rpc.RayException.formatted_exception_string', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='formattedExceptionString', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=871,
  serialized_end=1045,
)


_RUNTIMEENV = _descriptor.Descriptor(
  name='RuntimeEnv',
  full_name='ray.rpc.RuntimeEnv',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw_json', full_name='ray.rpc.RuntimeEnv.raw_json', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rawJson', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uris', full_name='ray.rpc.RuntimeEnv.uris', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='uris', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1047,
  serialized_end=1106,
)


_TASKSPEC_REQUIREDRESOURCESENTRY = _descriptor.Descriptor(
  name='RequiredResourcesEntry',
  full_name='ray.rpc.TaskSpec.RequiredResourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.TaskSpec.RequiredResourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.TaskSpec.RequiredResourcesEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2433,
  serialized_end=2501,
)

_TASKSPEC_REQUIREDPLACEMENTRESOURCESENTRY = _descriptor.Descriptor(
  name='RequiredPlacementResourcesEntry',
  full_name='ray.rpc.TaskSpec.RequiredPlacementResourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.TaskSpec.RequiredPlacementResourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.TaskSpec.RequiredPlacementResourcesEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2503,
  serialized_end=2580,
)

_TASKSPEC_OVERRIDEENVIRONMENTVARIABLESENTRY = _descriptor.Descriptor(
  name='OverrideEnvironmentVariablesEntry',
  full_name='ray.rpc.TaskSpec.OverrideEnvironmentVariablesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.TaskSpec.OverrideEnvironmentVariablesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.TaskSpec.OverrideEnvironmentVariablesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2582,
  serialized_end=2661,
)

_TASKSPEC = _descriptor.Descriptor(
  name='TaskSpec',
  full_name='ray.rpc.TaskSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='ray.rpc.TaskSpec.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.TaskSpec.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='ray.rpc.TaskSpec.language', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='language', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function_descriptor', full_name='ray.rpc.TaskSpec.function_descriptor', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='functionDescriptor', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.TaskSpec.job_id', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_id', full_name='ray.rpc.TaskSpec.task_id', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_task_id', full_name='ray.rpc.TaskSpec.parent_task_id', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parentTaskId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_counter', full_name='ray.rpc.TaskSpec.parent_counter', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parentCounter', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caller_id', full_name='ray.rpc.TaskSpec.caller_id', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='callerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='caller_address', full_name='ray.rpc.TaskSpec.caller_address', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='callerAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='ray.rpc.TaskSpec.args', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='args', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_returns', full_name='ray.rpc.TaskSpec.num_returns', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numReturns', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_resources', full_name='ray.rpc.TaskSpec.required_resources', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requiredResources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required_placement_resources', full_name='ray.rpc.TaskSpec.required_placement_resources', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requiredPlacementResources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_creation_task_spec', full_name='ray.rpc.TaskSpec.actor_creation_task_spec', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorCreationTaskSpec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_task_spec', full_name='ray.rpc.TaskSpec.actor_task_spec', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorTaskSpec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_retries', full_name='ray.rpc.TaskSpec.max_retries', index=16,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxRetries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='ray.rpc.TaskSpec.placement_group_id', index=17,
      number=18, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_group_bundle_index', full_name='ray.rpc.TaskSpec.placement_group_bundle_index', index=18,
      number=19, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupBundleIndex', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_group_capture_child_tasks', full_name='ray.rpc.TaskSpec.placement_group_capture_child_tasks', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupCaptureChildTasks', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_environment_variables', full_name='ray.rpc.TaskSpec.override_environment_variables', index=20,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='overrideEnvironmentVariables', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='skip_execution', full_name='ray.rpc.TaskSpec.skip_execution', index=21,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='skipExecution', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debugger_breakpoint', full_name='ray.rpc.TaskSpec.debugger_breakpoint', index=22,
      number=23, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='debuggerBreakpoint', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serialized_runtime_env', full_name='ray.rpc.TaskSpec.serialized_runtime_env', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='serializedRuntimeEnv', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TASKSPEC_REQUIREDRESOURCESENTRY, _TASKSPEC_REQUIREDPLACEMENTRESOURCESENTRY, _TASKSPEC_OVERRIDEENVIRONMENTVARIABLESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1109,
  serialized_end=2661,
)


_BUNDLE_BUNDLEIDENTIFIER = _descriptor.Descriptor(
  name='BundleIdentifier',
  full_name='ray.rpc.Bundle.BundleIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='ray.rpc.Bundle.BundleIdentifier.placement_group_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bundle_index', full_name='ray.rpc.Bundle.BundleIdentifier.bundle_index', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bundleIndex', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2837,
  serialized_end=2936,
)

_BUNDLE_UNITRESOURCESENTRY = _descriptor.Descriptor(
  name='UnitResourcesEntry',
  full_name='ray.rpc.Bundle.UnitResourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.Bundle.UnitResourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.Bundle.UnitResourcesEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2938,
  serialized_end=3002,
)

_BUNDLE = _descriptor.Descriptor(
  name='Bundle',
  full_name='ray.rpc.Bundle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bundle_id', full_name='ray.rpc.Bundle.bundle_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bundleId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit_resources', full_name='ray.rpc.Bundle.unit_resources', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='unitResources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='ray.rpc.Bundle.node_id', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BUNDLE_BUNDLEIDENTIFIER, _BUNDLE_UNITRESOURCESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2664,
  serialized_end=3002,
)


_PLACEMENTGROUPSPEC = _descriptor.Descriptor(
  name='PlacementGroupSpec',
  full_name='ray.rpc.PlacementGroupSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='placement_group_id', full_name='ray.rpc.PlacementGroupSpec.placement_group_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='placementGroupId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.PlacementGroupSpec.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bundles', full_name='ray.rpc.PlacementGroupSpec.bundles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bundles', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy', full_name='ray.rpc.PlacementGroupSpec.strategy', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='strategy', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_job_id', full_name='ray.rpc.PlacementGroupSpec.creator_job_id', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorJobId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_actor_id', full_name='ray.rpc.PlacementGroupSpec.creator_actor_id', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorActorId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_job_dead', full_name='ray.rpc.PlacementGroupSpec.creator_job_dead', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorJobDead', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='creator_actor_dead', full_name='ray.rpc.PlacementGroupSpec.creator_actor_dead', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='creatorActorDead', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_detached', full_name='ray.rpc.PlacementGroupSpec.is_detached', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isDetached', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3005,
  serialized_end=3391,
)


_OBJECTREFERENCE = _descriptor.Descriptor(
  name='ObjectReference',
  full_name='ray.rpc.ObjectReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_id', full_name='ray.rpc.ObjectReference.object_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner_address', full_name='ray.rpc.ObjectReference.owner_address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ownerAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3393,
  serialized_end=3494,
)


_OBJECTREFERENCECOUNT = _descriptor.Descriptor(
  name='ObjectReferenceCount',
  full_name='ray.rpc.ObjectReferenceCount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='ray.rpc.ObjectReferenceCount.reference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_local_ref', full_name='ray.rpc.ObjectReferenceCount.has_local_ref', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='hasLocalRef', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='borrowers', full_name='ray.rpc.ObjectReferenceCount.borrowers', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='borrowers', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_in_objects', full_name='ray.rpc.ObjectReferenceCount.stored_in_objects', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='storedInObjects', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contained_in_borrowed_id', full_name='ray.rpc.ObjectReferenceCount.contained_in_borrowed_id', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='containedInBorrowedId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contains', full_name='ray.rpc.ObjectReferenceCount.contains', index=5,
      number=6, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='contains', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3497,
  serialized_end=3814,
)


_TASKARG = _descriptor.Descriptor(
  name='TaskArg',
  full_name='ray.rpc.TaskArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_ref', full_name='ray.rpc.TaskArg.object_ref', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectRef', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='ray.rpc.TaskArg.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='data', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='ray.rpc.TaskArg.metadata', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nested_inlined_ids', full_name='ray.rpc.TaskArg.nested_inlined_ids', index=3,
      number=4, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nestedInlinedIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3817,
  serialized_end=3977,
)


_ACTORCREATIONTASKSPEC = _descriptor.Descriptor(
  name='ActorCreationTaskSpec',
  full_name='ray.rpc.ActorCreationTaskSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='ray.rpc.ActorCreationTaskSpec.actor_id', index=0,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_actor_restarts', full_name='ray.rpc.ActorCreationTaskSpec.max_actor_restarts', index=1,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxActorRestarts', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_task_retries', full_name='ray.rpc.ActorCreationTaskSpec.max_task_retries', index=2,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxTaskRetries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_worker_options', full_name='ray.rpc.ActorCreationTaskSpec.dynamic_worker_options', index=3,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dynamicWorkerOptions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_concurrency', full_name='ray.rpc.ActorCreationTaskSpec.max_concurrency', index=4,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='maxConcurrency', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_detached', full_name='ray.rpc.ActorCreationTaskSpec.is_detached', index=5,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isDetached', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.ActorCreationTaskSpec.name', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_asyncio', full_name='ray.rpc.ActorCreationTaskSpec.is_asyncio', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isAsyncio', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_data', full_name='ray.rpc.ActorCreationTaskSpec.extension_data', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='extensionData', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3980,
  serialized_end=4336,
)


_ACTORTASKSPEC = _descriptor.Descriptor(
  name='ActorTaskSpec',
  full_name='ray.rpc.ActorTaskSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='ray.rpc.ActorTaskSpec.actor_id', index=0,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_creation_dummy_object_id', full_name='ray.rpc.ActorTaskSpec.actor_creation_dummy_object_id', index=1,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorCreationDummyObjectId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_counter', full_name='ray.rpc.ActorTaskSpec.actor_counter', index=2,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorCounter', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_actor_task_dummy_object_id', full_name='ray.rpc.ActorTaskSpec.previous_actor_task_dummy_object_id', index=3,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='previousActorTaskDummyObjectId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4339,
  serialized_end=4563,
)


_TASKEXECUTIONSPEC = _descriptor.Descriptor(
  name='TaskExecutionSpec',
  full_name='ray.rpc.TaskExecutionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_timestamp', full_name='ray.rpc.TaskExecutionSpec.last_timestamp', index=0,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='lastTimestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_forwards', full_name='ray.rpc.TaskExecutionSpec.num_forwards', index=1,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numForwards', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4565,
  serialized_end=4658,
)


_TASK = _descriptor.Descriptor(
  name='Task',
  full_name='ray.rpc.Task',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task_spec', full_name='ray.rpc.Task.task_spec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskSpec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_execution_spec', full_name='ray.rpc.Task.task_execution_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskExecutionSpec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4661,
  serialized_end=4791,
)


_RESOURCEID = _descriptor.Descriptor(
  name='ResourceId',
  full_name='ray.rpc.ResourceId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='ray.rpc.ResourceId.index', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='index', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='ray.rpc.ResourceId.quantity', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='quantity', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4793,
  serialized_end=4855,
)


_RESOURCEMAPENTRY = _descriptor.Descriptor(
  name='ResourceMapEntry',
  full_name='ray.rpc.ResourceMapEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ray.rpc.ResourceMapEntry.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_ids', full_name='ray.rpc.ResourceMapEntry.resource_ids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceIds', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4857,
  serialized_end=4951,
)


_VIEWDATA_MEASURE = _descriptor.Descriptor(
  name='Measure',
  full_name='ray.rpc.ViewData.Measure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tags', full_name='ray.rpc.ViewData.Measure.tags', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tags', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='ray.rpc.ViewData.Measure.int_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='intValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='ray.rpc.ViewData.Measure.double_value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='doubleValue', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution_min', full_name='ray.rpc.ViewData.Measure.distribution_min', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='distributionMin', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution_mean', full_name='ray.rpc.ViewData.Measure.distribution_mean', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='distributionMean', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution_max', full_name='ray.rpc.ViewData.Measure.distribution_max', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='distributionMax', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution_count', full_name='ray.rpc.ViewData.Measure.distribution_count', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='distributionCount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution_bucket_boundaries', full_name='ray.rpc.ViewData.Measure.distribution_bucket_boundaries', index=7,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='distributionBucketBoundaries', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='distribution_bucket_counts', full_name='ray.rpc.ViewData.Measure.distribution_bucket_counts', index=8,
      number=9, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='distributionBucketCounts', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5051,
  serialized_end=5454,
)

_VIEWDATA = _descriptor.Descriptor(
  name='ViewData',
  full_name='ray.rpc.ViewData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_name', full_name='ray.rpc.ViewData.view_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='viewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measures', full_name='ray.rpc.ViewData.measures', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='measures', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VIEWDATA_MEASURE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4954,
  serialized_end=5454,
)


_OBJECTREFINFO = _descriptor.Descriptor(
  name='ObjectRefInfo',
  full_name='ray.rpc.ObjectRefInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='object_id', full_name='ray.rpc.ObjectRefInfo.object_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='call_site', full_name='ray.rpc.ObjectRefInfo.call_site', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='callSite', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_size', full_name='ray.rpc.ObjectRefInfo.object_size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_ref_count', full_name='ray.rpc.ObjectRefInfo.local_ref_count', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='localRefCount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='submitted_task_ref_count', full_name='ray.rpc.ObjectRefInfo.submitted_task_ref_count', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='submittedTaskRefCount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contained_in_owned', full_name='ray.rpc.ObjectRefInfo.contained_in_owned', index=5,
      number=6, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='containedInOwned', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pinned_in_memory', full_name='ray.rpc.ObjectRefInfo.pinned_in_memory', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pinnedInMemory', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5457,
  serialized_end=5748,
)


_RESOURCEALLOCATIONS_RESOURCESLOT = _descriptor.Descriptor(
  name='ResourceSlot',
  full_name='ray.rpc.ResourceAllocations.ResourceSlot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='slot', full_name='ray.rpc.ResourceAllocations.ResourceSlot.slot', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slot', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocation', full_name='ray.rpc.ResourceAllocations.ResourceSlot.allocation', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='allocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5856,
  serialized_end=5922,
)

_RESOURCEALLOCATIONS = _descriptor.Descriptor(
  name='ResourceAllocations',
  full_name='ray.rpc.ResourceAllocations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_slots', full_name='ray.rpc.ResourceAllocations.resource_slots', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resourceSlots', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEALLOCATIONS_RESOURCESLOT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5751,
  serialized_end=5922,
)


_COREWORKERSTATS_USEDRESOURCESENTRY = _descriptor.Descriptor(
  name='UsedResourcesEntry',
  full_name='ray.rpc.CoreWorkerStats.UsedResourcesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.CoreWorkerStats.UsedResourcesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.CoreWorkerStats.UsedResourcesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6916,
  serialized_end=7010,
)

_COREWORKERSTATS_WEBUIDISPLAYENTRY = _descriptor.Descriptor(
  name='WebuiDisplayEntry',
  full_name='ray.rpc.CoreWorkerStats.WebuiDisplayEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.CoreWorkerStats.WebuiDisplayEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.CoreWorkerStats.WebuiDisplayEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7012,
  serialized_end=7075,
)

_COREWORKERSTATS = _descriptor.Descriptor(
  name='CoreWorkerStats',
  full_name='ray.rpc.CoreWorkerStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='current_task_desc', full_name='ray.rpc.CoreWorkerStats.current_task_desc', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='currentTaskDesc', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_pending_tasks', full_name='ray.rpc.CoreWorkerStats.num_pending_tasks', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numPendingTasks', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_object_refs_in_scope', full_name='ray.rpc.CoreWorkerStats.num_object_refs_in_scope', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numObjectRefsInScope', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_task_name', full_name='ray.rpc.CoreWorkerStats.current_task_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='currentTaskName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_task_func_desc', full_name='ray.rpc.CoreWorkerStats.current_task_func_desc', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='currentTaskFuncDesc', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='ray.rpc.CoreWorkerStats.ip_address', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ipAddress', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='ray.rpc.CoreWorkerStats.port', index=6,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='port', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_id', full_name='ray.rpc.CoreWorkerStats.actor_id', index=7,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='used_resources', full_name='ray.rpc.CoreWorkerStats.used_resources', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='usedResources', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='webui_display', full_name='ray.rpc.CoreWorkerStats.webui_display', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='webuiDisplay', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_in_plasma', full_name='ray.rpc.CoreWorkerStats.num_in_plasma', index=10,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numInPlasma', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_local_objects', full_name='ray.rpc.CoreWorkerStats.num_local_objects', index=11,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numLocalObjects', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='used_object_store_memory', full_name='ray.rpc.CoreWorkerStats.used_object_store_memory', index=12,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='usedObjectStoreMemory', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_queue_length', full_name='ray.rpc.CoreWorkerStats.task_queue_length', index=13,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='taskQueueLength', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_executed_tasks', full_name='ray.rpc.CoreWorkerStats.num_executed_tasks', index=14,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numExecutedTasks', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actor_title', full_name='ray.rpc.CoreWorkerStats.actor_title', index=15,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='actorTitle', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_refs', full_name='ray.rpc.CoreWorkerStats.object_refs', index=16,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='objectRefs', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='ray.rpc.CoreWorkerStats.job_id', index=17,
      number=19, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jobId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_id', full_name='ray.rpc.CoreWorkerStats.worker_id', index=18,
      number=20, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='ray.rpc.CoreWorkerStats.language', index=19,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='language', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pid', full_name='ray.rpc.CoreWorkerStats.pid', index=20,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pid', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='worker_type', full_name='ray.rpc.CoreWorkerStats.worker_type', index=21,
      number=23, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='workerType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COREWORKERSTATS_USEDRESOURCESENTRY, _COREWORKERSTATS_WEBUIDISPLAYENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5925,
  serialized_end=7075,
)


_METRICPOINT_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='ray.rpc.MetricPoint.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='ray.rpc.MetricPoint.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.MetricPoint.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7286,
  serialized_end=7341,
)

_METRICPOINT = _descriptor.Descriptor(
  name='MetricPoint',
  full_name='ray.rpc.MetricPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metric_name', full_name='ray.rpc.MetricPoint.metric_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metricName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='ray.rpc.MetricPoint.timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timestamp', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='ray.rpc.MetricPoint.value', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='ray.rpc.MetricPoint.tags', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tags', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='ray.rpc.MetricPoint.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='description', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='units', full_name='ray.rpc.MetricPoint.units', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='units', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_METRICPOINT_TAGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7078,
  serialized_end=7341,
)

_FUNCTIONDESCRIPTOR.fields_by_name['java_function_descriptor'].message_type = _JAVAFUNCTIONDESCRIPTOR
_FUNCTIONDESCRIPTOR.fields_by_name['python_function_descriptor'].message_type = _PYTHONFUNCTIONDESCRIPTOR
_FUNCTIONDESCRIPTOR.fields_by_name['cpp_function_descriptor'].message_type = _CPPFUNCTIONDESCRIPTOR
_FUNCTIONDESCRIPTOR.oneofs_by_name['function_descriptor'].fields.append(
  _FUNCTIONDESCRIPTOR.fields_by_name['java_function_descriptor'])
_FUNCTIONDESCRIPTOR.fields_by_name['java_function_descriptor'].containing_oneof = _FUNCTIONDESCRIPTOR.oneofs_by_name['function_descriptor']
_FUNCTIONDESCRIPTOR.oneofs_by_name['function_descriptor'].fields.append(
  _FUNCTIONDESCRIPTOR.fields_by_name['python_function_descriptor'])
_FUNCTIONDESCRIPTOR.fields_by_name['python_function_descriptor'].containing_oneof = _FUNCTIONDESCRIPTOR.oneofs_by_name['function_descriptor']
_FUNCTIONDESCRIPTOR.oneofs_by_name['function_descriptor'].fields.append(
  _FUNCTIONDESCRIPTOR.fields_by_name['cpp_function_descriptor'])
_FUNCTIONDESCRIPTOR.fields_by_name['cpp_function_descriptor'].containing_oneof = _FUNCTIONDESCRIPTOR.oneofs_by_name['function_descriptor']
_RAYEXCEPTION.fields_by_name['language'].enum_type = _LANGUAGE
_TASKSPEC_REQUIREDRESOURCESENTRY.containing_type = _TASKSPEC
_TASKSPEC_REQUIREDPLACEMENTRESOURCESENTRY.containing_type = _TASKSPEC
_TASKSPEC_OVERRIDEENVIRONMENTVARIABLESENTRY.containing_type = _TASKSPEC
_TASKSPEC.fields_by_name['type'].enum_type = _TASKTYPE
_TASKSPEC.fields_by_name['language'].enum_type = _LANGUAGE
_TASKSPEC.fields_by_name['function_descriptor'].message_type = _FUNCTIONDESCRIPTOR
_TASKSPEC.fields_by_name['caller_address'].message_type = _ADDRESS
_TASKSPEC.fields_by_name['args'].message_type = _TASKARG
_TASKSPEC.fields_by_name['required_resources'].message_type = _TASKSPEC_REQUIREDRESOURCESENTRY
_TASKSPEC.fields_by_name['required_placement_resources'].message_type = _TASKSPEC_REQUIREDPLACEMENTRESOURCESENTRY
_TASKSPEC.fields_by_name['actor_creation_task_spec'].message_type = _ACTORCREATIONTASKSPEC
_TASKSPEC.fields_by_name['actor_task_spec'].message_type = _ACTORTASKSPEC
_TASKSPEC.fields_by_name['override_environment_variables'].message_type = _TASKSPEC_OVERRIDEENVIRONMENTVARIABLESENTRY
_BUNDLE_BUNDLEIDENTIFIER.containing_type = _BUNDLE
_BUNDLE_UNITRESOURCESENTRY.containing_type = _BUNDLE
_BUNDLE.fields_by_name['bundle_id'].message_type = _BUNDLE_BUNDLEIDENTIFIER
_BUNDLE.fields_by_name['unit_resources'].message_type = _BUNDLE_UNITRESOURCESENTRY
_PLACEMENTGROUPSPEC.fields_by_name['bundles'].message_type = _BUNDLE
_PLACEMENTGROUPSPEC.fields_by_name['strategy'].enum_type = _PLACEMENTSTRATEGY
_OBJECTREFERENCE.fields_by_name['owner_address'].message_type = _ADDRESS
_OBJECTREFERENCECOUNT.fields_by_name['reference'].message_type = _OBJECTREFERENCE
_OBJECTREFERENCECOUNT.fields_by_name['borrowers'].message_type = _ADDRESS
_OBJECTREFERENCECOUNT.fields_by_name['stored_in_objects'].message_type = _OBJECTREFERENCE
_TASKARG.fields_by_name['object_ref'].message_type = _OBJECTREFERENCE
_TASK.fields_by_name['task_spec'].message_type = _TASKSPEC
_TASK.fields_by_name['task_execution_spec'].message_type = _TASKEXECUTIONSPEC
_RESOURCEMAPENTRY.fields_by_name['resource_ids'].message_type = _RESOURCEID
_VIEWDATA_MEASURE.containing_type = _VIEWDATA
_VIEWDATA.fields_by_name['measures'].message_type = _VIEWDATA_MEASURE
_RESOURCEALLOCATIONS_RESOURCESLOT.containing_type = _RESOURCEALLOCATIONS
_RESOURCEALLOCATIONS.fields_by_name['resource_slots'].message_type = _RESOURCEALLOCATIONS_RESOURCESLOT
_COREWORKERSTATS_USEDRESOURCESENTRY.fields_by_name['value'].message_type = _RESOURCEALLOCATIONS
_COREWORKERSTATS_USEDRESOURCESENTRY.containing_type = _COREWORKERSTATS
_COREWORKERSTATS_WEBUIDISPLAYENTRY.containing_type = _COREWORKERSTATS
_COREWORKERSTATS.fields_by_name['used_resources'].message_type = _COREWORKERSTATS_USEDRESOURCESENTRY
_COREWORKERSTATS.fields_by_name['webui_display'].message_type = _COREWORKERSTATS_WEBUIDISPLAYENTRY
_COREWORKERSTATS.fields_by_name['object_refs'].message_type = _OBJECTREFINFO
_COREWORKERSTATS.fields_by_name['language'].enum_type = _LANGUAGE
_COREWORKERSTATS.fields_by_name['worker_type'].enum_type = _WORKERTYPE
_METRICPOINT_TAGSENTRY.containing_type = _METRICPOINT
_METRICPOINT.fields_by_name['tags'].message_type = _METRICPOINT_TAGSENTRY
DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
DESCRIPTOR.message_types_by_name['JavaFunctionDescriptor'] = _JAVAFUNCTIONDESCRIPTOR
DESCRIPTOR.message_types_by_name['PythonFunctionDescriptor'] = _PYTHONFUNCTIONDESCRIPTOR
DESCRIPTOR.message_types_by_name['CppFunctionDescriptor'] = _CPPFUNCTIONDESCRIPTOR
DESCRIPTOR.message_types_by_name['FunctionDescriptor'] = _FUNCTIONDESCRIPTOR
DESCRIPTOR.message_types_by_name['RayException'] = _RAYEXCEPTION
DESCRIPTOR.message_types_by_name['RuntimeEnv'] = _RUNTIMEENV
DESCRIPTOR.message_types_by_name['TaskSpec'] = _TASKSPEC
DESCRIPTOR.message_types_by_name['Bundle'] = _BUNDLE
DESCRIPTOR.message_types_by_name['PlacementGroupSpec'] = _PLACEMENTGROUPSPEC
DESCRIPTOR.message_types_by_name['ObjectReference'] = _OBJECTREFERENCE
DESCRIPTOR.message_types_by_name['ObjectReferenceCount'] = _OBJECTREFERENCECOUNT
DESCRIPTOR.message_types_by_name['TaskArg'] = _TASKARG
DESCRIPTOR.message_types_by_name['ActorCreationTaskSpec'] = _ACTORCREATIONTASKSPEC
DESCRIPTOR.message_types_by_name['ActorTaskSpec'] = _ACTORTASKSPEC
DESCRIPTOR.message_types_by_name['TaskExecutionSpec'] = _TASKEXECUTIONSPEC
DESCRIPTOR.message_types_by_name['Task'] = _TASK
DESCRIPTOR.message_types_by_name['ResourceId'] = _RESOURCEID
DESCRIPTOR.message_types_by_name['ResourceMapEntry'] = _RESOURCEMAPENTRY
DESCRIPTOR.message_types_by_name['ViewData'] = _VIEWDATA
DESCRIPTOR.message_types_by_name['ObjectRefInfo'] = _OBJECTREFINFO
DESCRIPTOR.message_types_by_name['ResourceAllocations'] = _RESOURCEALLOCATIONS
DESCRIPTOR.message_types_by_name['CoreWorkerStats'] = _COREWORKERSTATS
DESCRIPTOR.message_types_by_name['MetricPoint'] = _METRICPOINT
DESCRIPTOR.enum_types_by_name['Language'] = _LANGUAGE
DESCRIPTOR.enum_types_by_name['WorkerType'] = _WORKERTYPE
DESCRIPTOR.enum_types_by_name['TaskType'] = _TASKTYPE
DESCRIPTOR.enum_types_by_name['ErrorType'] = _ERRORTYPE
DESCRIPTOR.enum_types_by_name['WorkerExitType'] = _WORKEREXITTYPE
DESCRIPTOR.enum_types_by_name['PlacementStrategy'] = _PLACEMENTSTRATEGY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.Address)
  })
_sym_db.RegisterMessage(Address)

JavaFunctionDescriptor = _reflection.GeneratedProtocolMessageType('JavaFunctionDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _JAVAFUNCTIONDESCRIPTOR,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.JavaFunctionDescriptor)
  })
_sym_db.RegisterMessage(JavaFunctionDescriptor)

PythonFunctionDescriptor = _reflection.GeneratedProtocolMessageType('PythonFunctionDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _PYTHONFUNCTIONDESCRIPTOR,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PythonFunctionDescriptor)
  })
_sym_db.RegisterMessage(PythonFunctionDescriptor)

CppFunctionDescriptor = _reflection.GeneratedProtocolMessageType('CppFunctionDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _CPPFUNCTIONDESCRIPTOR,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CppFunctionDescriptor)
  })
_sym_db.RegisterMessage(CppFunctionDescriptor)

FunctionDescriptor = _reflection.GeneratedProtocolMessageType('FunctionDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _FUNCTIONDESCRIPTOR,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.FunctionDescriptor)
  })
_sym_db.RegisterMessage(FunctionDescriptor)

RayException = _reflection.GeneratedProtocolMessageType('RayException', (_message.Message,), {
  'DESCRIPTOR' : _RAYEXCEPTION,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RayException)
  })
_sym_db.RegisterMessage(RayException)

RuntimeEnv = _reflection.GeneratedProtocolMessageType('RuntimeEnv', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEENV,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.RuntimeEnv)
  })
_sym_db.RegisterMessage(RuntimeEnv)

TaskSpec = _reflection.GeneratedProtocolMessageType('TaskSpec', (_message.Message,), {

  'RequiredResourcesEntry' : _reflection.GeneratedProtocolMessageType('RequiredResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _TASKSPEC_REQUIREDRESOURCESENTRY,
    '__module__' : 'src.ray.protobuf.common_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.TaskSpec.RequiredResourcesEntry)
    })
  ,

  'RequiredPlacementResourcesEntry' : _reflection.GeneratedProtocolMessageType('RequiredPlacementResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _TASKSPEC_REQUIREDPLACEMENTRESOURCESENTRY,
    '__module__' : 'src.ray.protobuf.common_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.TaskSpec.RequiredPlacementResourcesEntry)
    })
  ,

  'OverrideEnvironmentVariablesEntry' : _reflection.GeneratedProtocolMessageType('OverrideEnvironmentVariablesEntry', (_message.Message,), {
    'DESCRIPTOR' : _TASKSPEC_OVERRIDEENVIRONMENTVARIABLESENTRY,
    '__module__' : 'src.ray.protobuf.common_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.TaskSpec.OverrideEnvironmentVariablesEntry)
    })
  ,
  'DESCRIPTOR' : _TASKSPEC,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TaskSpec)
  })
_sym_db.RegisterMessage(TaskSpec)
_sym_db.RegisterMessage(TaskSpec.RequiredResourcesEntry)
_sym_db.RegisterMessage(TaskSpec.RequiredPlacementResourcesEntry)
_sym_db.RegisterMessage(TaskSpec.OverrideEnvironmentVariablesEntry)

Bundle = _reflection.GeneratedProtocolMessageType('Bundle', (_message.Message,), {

  'BundleIdentifier' : _reflection.GeneratedProtocolMessageType('BundleIdentifier', (_message.Message,), {
    'DESCRIPTOR' : _BUNDLE_BUNDLEIDENTIFIER,
    '__module__' : 'src.ray.protobuf.common_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.Bundle.BundleIdentifier)
    })
  ,

  'UnitResourcesEntry' : _reflection.GeneratedProtocolMessageType('UnitResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _BUNDLE_UNITRESOURCESENTRY,
    '__module__' : 'src.ray.protobuf.common_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.Bundle.UnitResourcesEntry)
    })
  ,
  'DESCRIPTOR' : _BUNDLE,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.Bundle)
  })
_sym_db.RegisterMessage(Bundle)
_sym_db.RegisterMessage(Bundle.BundleIdentifier)
_sym_db.RegisterMessage(Bundle.UnitResourcesEntry)

PlacementGroupSpec = _reflection.GeneratedProtocolMessageType('PlacementGroupSpec', (_message.Message,), {
  'DESCRIPTOR' : _PLACEMENTGROUPSPEC,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.PlacementGroupSpec)
  })
_sym_db.RegisterMessage(PlacementGroupSpec)

ObjectReference = _reflection.GeneratedProtocolMessageType('ObjectReference', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTREFERENCE,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ObjectReference)
  })
_sym_db.RegisterMessage(ObjectReference)

ObjectReferenceCount = _reflection.GeneratedProtocolMessageType('ObjectReferenceCount', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTREFERENCECOUNT,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ObjectReferenceCount)
  })
_sym_db.RegisterMessage(ObjectReferenceCount)

TaskArg = _reflection.GeneratedProtocolMessageType('TaskArg', (_message.Message,), {
  'DESCRIPTOR' : _TASKARG,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TaskArg)
  })
_sym_db.RegisterMessage(TaskArg)

ActorCreationTaskSpec = _reflection.GeneratedProtocolMessageType('ActorCreationTaskSpec', (_message.Message,), {
  'DESCRIPTOR' : _ACTORCREATIONTASKSPEC,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ActorCreationTaskSpec)
  })
_sym_db.RegisterMessage(ActorCreationTaskSpec)

ActorTaskSpec = _reflection.GeneratedProtocolMessageType('ActorTaskSpec', (_message.Message,), {
  'DESCRIPTOR' : _ACTORTASKSPEC,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ActorTaskSpec)
  })
_sym_db.RegisterMessage(ActorTaskSpec)

TaskExecutionSpec = _reflection.GeneratedProtocolMessageType('TaskExecutionSpec', (_message.Message,), {
  'DESCRIPTOR' : _TASKEXECUTIONSPEC,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.TaskExecutionSpec)
  })
_sym_db.RegisterMessage(TaskExecutionSpec)

Task = _reflection.GeneratedProtocolMessageType('Task', (_message.Message,), {
  'DESCRIPTOR' : _TASK,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.Task)
  })
_sym_db.RegisterMessage(Task)

ResourceId = _reflection.GeneratedProtocolMessageType('ResourceId', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEID,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceId)
  })
_sym_db.RegisterMessage(ResourceId)

ResourceMapEntry = _reflection.GeneratedProtocolMessageType('ResourceMapEntry', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEMAPENTRY,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceMapEntry)
  })
_sym_db.RegisterMessage(ResourceMapEntry)

ViewData = _reflection.GeneratedProtocolMessageType('ViewData', (_message.Message,), {

  'Measure' : _reflection.GeneratedProtocolMessageType('Measure', (_message.Message,), {
    'DESCRIPTOR' : _VIEWDATA_MEASURE,
    '__module__' : 'src.ray.protobuf.common_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ViewData.Measure)
    })
  ,
  'DESCRIPTOR' : _VIEWDATA,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ViewData)
  })
_sym_db.RegisterMessage(ViewData)
_sym_db.RegisterMessage(ViewData.Measure)

ObjectRefInfo = _reflection.GeneratedProtocolMessageType('ObjectRefInfo', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTREFINFO,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ObjectRefInfo)
  })
_sym_db.RegisterMessage(ObjectRefInfo)

ResourceAllocations = _reflection.GeneratedProtocolMessageType('ResourceAllocations', (_message.Message,), {

  'ResourceSlot' : _reflection.GeneratedProtocolMessageType('ResourceSlot', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEALLOCATIONS_RESOURCESLOT,
    '__module__' : 'src.ray.protobuf.common_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.ResourceAllocations.ResourceSlot)
    })
  ,
  'DESCRIPTOR' : _RESOURCEALLOCATIONS,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.ResourceAllocations)
  })
_sym_db.RegisterMessage(ResourceAllocations)
_sym_db.RegisterMessage(ResourceAllocations.ResourceSlot)

CoreWorkerStats = _reflection.GeneratedProtocolMessageType('CoreWorkerStats', (_message.Message,), {

  'UsedResourcesEntry' : _reflection.GeneratedProtocolMessageType('UsedResourcesEntry', (_message.Message,), {
    'DESCRIPTOR' : _COREWORKERSTATS_USEDRESOURCESENTRY,
    '__module__' : 'src.ray.protobuf.common_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.CoreWorkerStats.UsedResourcesEntry)
    })
  ,

  'WebuiDisplayEntry' : _reflection.GeneratedProtocolMessageType('WebuiDisplayEntry', (_message.Message,), {
    'DESCRIPTOR' : _COREWORKERSTATS_WEBUIDISPLAYENTRY,
    '__module__' : 'src.ray.protobuf.common_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.CoreWorkerStats.WebuiDisplayEntry)
    })
  ,
  'DESCRIPTOR' : _COREWORKERSTATS,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.CoreWorkerStats)
  })
_sym_db.RegisterMessage(CoreWorkerStats)
_sym_db.RegisterMessage(CoreWorkerStats.UsedResourcesEntry)
_sym_db.RegisterMessage(CoreWorkerStats.WebuiDisplayEntry)

MetricPoint = _reflection.GeneratedProtocolMessageType('MetricPoint', (_message.Message,), {

  'TagsEntry' : _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), {
    'DESCRIPTOR' : _METRICPOINT_TAGSENTRY,
    '__module__' : 'src.ray.protobuf.common_pb2'
    # @@protoc_insertion_point(class_scope:ray.rpc.MetricPoint.TagsEntry)
    })
  ,
  'DESCRIPTOR' : _METRICPOINT,
  '__module__' : 'src.ray.protobuf.common_pb2'
  # @@protoc_insertion_point(class_scope:ray.rpc.MetricPoint)
  })
_sym_db.RegisterMessage(MetricPoint)
_sym_db.RegisterMessage(MetricPoint.TagsEntry)


DESCRIPTOR._options = None
_TASKSPEC_REQUIREDRESOURCESENTRY._options = None
_TASKSPEC_REQUIREDPLACEMENTRESOURCESENTRY._options = None
_TASKSPEC_OVERRIDEENVIRONMENTVARIABLESENTRY._options = None
_BUNDLE_UNITRESOURCESENTRY._options = None
_COREWORKERSTATS_USEDRESOURCESENTRY._options = None
_COREWORKERSTATS_WEBUIDISPLAYENTRY._options = None
_METRICPOINT_TAGSENTRY._options = None
# @@protoc_insertion_point(module_scope)
